SELECT
  -- Main Fields
  id, ARRAY(SELECT DISTINCT(type) FROM UNNEST(types) as type) as types, name, country, country_code, region, subregion, coordinates,
  -- Filters
  (SELECT SUM(combined.total) from UNNEST(years)) as total_publications,
  ARRAY_LENGTH(years) as total_years,
  SAFE_DIVIDE((SELECT SUM(combined.total) from UNNEST(years)), ARRAY_LENGTH(years)) as average_per_year,
  (SELECT MIN(published_year) from UNNEST(years)) as first_year,
  (SELECT MAX(published_year) from UNNEST(years)) as last_year,
  -- Per year Information
   years
FROM(
  SELECT
    base.grid_id as id,
    ARRAY_CONCAT_AGG(types) as types,
    MAX(base.name) as name,
    MAX(country) as country,
    MAX(country_code) as country_code,
    MAX(region) as region,
    MAX(subregion) as subregion,
    MAX(coordinates ) as coordinates,
    ARRAY_AGG(
      STRUCT(base.published_year, 
         STRUCT(
             total, total_oa, total_citations, articles_with_citations, articles_without_citations, citations_per_article, citations_per_citated_article, oa_citations, gold_citations, green_citations, green_only_citations, hybrid_citations, bronze_citations, open_access, gold, green, green_only, green_in_home_repo, percent_in_home_repo, percent_of_just_green_in_home_repo, hybrid, bronze, percent_OA, percent_green, percent_green_only, percent_gold, percent_gold_doaj, percent_hybrid, percent_bronze, output_types, 
             collaborators.collaborations as collaborations,
             ARRAY((SELECT as STRUCT funder.name, COUNT(*) as count, COUNTIF(is_oa) as oa, COUNTIF(green) as green, COUNTIF(gold) as gold FROM UNNEST(funders) as funder GROUP BY funder.name)) as funders,
             ARRAY((SELECT as STRUCT publisher, COUNT(*) as count, COUNTIF(is_oa) as oa, COUNTIF(green) as green, COUNTIF(gold) as gold FROM UNNEST(publishers) GROUP BY publisher)) as publishers,
             ARRAY((SELECT as STRUCT journal, COUNT(*) as count, COUNTIF(is_oa) as oa, COUNTIF(green) as green, COUNTIF(gold) as gold FROM UNNEST(journals) GROUP BY journal)) as journals,
             [
              STRUCT("twitter" as source, (SELECT SUM(count) as count FROM UNNEST(alt_metrics) WHERE source = 'twitter') as count),
              STRUCT("wikipedia" as source, (SELECT SUM(count) as count FROM UNNEST(alt_metrics) WHERE source = 'wikipedia') as count),
              STRUCT("newsfeed" as source, (SELECT SUM(count) as count FROM UNNEST(alt_metrics) WHERE source = 'newsfeed') as count),
              STRUCT("reddit-links" as source, (SELECT SUM(count) as count FROM UNNEST(alt_metrics) WHERE source = 'reddit-links') as count),
              STRUCT("reddit" as source, (SELECT SUM(count) as count FROM UNNEST(alt_metrics) WHERE source = 'reddit') as count),
              STRUCT("datacite" as source, (SELECT SUM(count) as count FROM UNNEST(alt_metrics) WHERE source = 'datacite') as count),
              STRUCT("wordpressdotcom" as source, (SELECT SUM(count) as count FROM UNNEST(alt_metrics) WHERE source = 'wordpressdotcom') as count),
              STRUCT("plaudit" as source, (SELECT SUM(count) as count FROM UNNEST(alt_metrics) WHERE source = 'plaudit') as count),
              STRUCT("stackexchange" as source, (SELECT SUM(count) as count FROM UNNEST(alt_metrics) WHERE source = 'stackexchange') as count),
              STRUCT("cambia-lens" as source, (SELECT SUM(count) as count FROM UNNEST(alt_metrics) WHERE source = 'cambia-lens') as count),
              STRUCT("hypothesis" as source, (SELECT SUM(count) as count FROM UNNEST(alt_metrics) WHERE source = 'hypothesis') as count),
              STRUCT("f1000" as source, (SELECT SUM(count) as count FROM UNNEST(alt_metrics) WHERE source = 'f1000') as count),
              STRUCT("web" as source, (SELECT SUM(count) as count FROM UNNEST(alt_metrics) WHERE source = 'web') as count),
              STRUCT("crossref" as source, (SELECT SUM(count) as count FROM UNNEST(alt_metrics) WHERE source = 'crossref') as count)
             ] as events,
             ARRAY((SELECT as STRUCT 
                        unpaywall.unpaywall_release, 
                        COUNT(*) as total, 
                        COUNTIF(is_oa) as total_oa, 
                        COUNTIF(green) as green, 
                        COUNTIF(gold) as gold,
                        -- Output type counts
                        [
                          STRUCT("journal_articles" as type, 
                            COUNTIF(unpaywall.output_type = 'journal-article') as count, 
                            COUNTIF(unpaywall.output_type = 'journal-article' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'journal-article' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'journal-article' AND unpaywall.gold) as is_gold),

                          STRUCT("book_sections" as type, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter')) as count, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter') AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter') AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter') AND unpaywall.gold) as is_gold),

                          STRUCT("authored_books" as type, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph')) as count, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph') AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph') AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph') AND unpaywall.gold) as is_gold),

                          STRUCT("edited_volumes" as type, 
                            COUNTIF(unpaywall.output_type = 'edited-book') as count, 
                            COUNTIF(unpaywall.output_type = 'edited-book' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'edited-book' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'edited-book' AND unpaywall.gold) as is_gold),

                          STRUCT("reports" as type, 
                            COUNTIF(unpaywall.output_type = 'report') as count, 
                            COUNTIF(unpaywall.output_type = 'report' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'report' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'report' AND unpaywall.gold) as is_gold),

                          STRUCT("datasets" as type, 
                            COUNTIF(unpaywall.output_type = 'dataset') as count, 
                            COUNTIF(unpaywall.output_type = 'dataset' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'dataset' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'dataset' AND unpaywall.gold) as is_gold),

                          STRUCT("proceedings_article" as type, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article') as count, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article' AND unpaywall.gold) as is_gold),

                          STRUCT("other_outputs" as type, 
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article')) as count, 
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article') AND unpaywall.is_oa) as is_oa,
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article') AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article') AND unpaywall.gold) as is_gold)
                        ] as output_types
                        
                    FROM UNNEST(unpaywall_history) as unpaywall GROUP BY unpaywall.unpaywall_release)) as unpaywall_history
             --diversity as diversity
             ) as combined,
          STRUCT(
              just_scopus_total as total, just_scopus_total_oa as total_oa, 
              ARRAY((SELECT as STRUCT 
                        unpaywall.unpaywall_release, 
                        COUNT(*) as total, 
                        COUNTIF(is_oa) as total_oa, 
                        COUNTIF(green) as green, 
                        COUNTIF(gold) as gold,
                        -- Output type counts
                        [
                          STRUCT("journal_articles" as type, 
                            COUNTIF(unpaywall.output_type = 'journal-article') as count, 
                            COUNTIF(unpaywall.output_type = 'journal-article' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'journal-article' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'journal-article' AND unpaywall.gold) as is_gold),

                          STRUCT("book_sections" as type, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter')) as count, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter') AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter') AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter') AND unpaywall.gold) as is_gold),

                          STRUCT("authored_books" as type, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph')) as count, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph') AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph') AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph') AND unpaywall.gold) as is_gold),

                          STRUCT("edited_volumes" as type, 
                            COUNTIF(unpaywall.output_type = 'edited-book') as count, 
                            COUNTIF(unpaywall.output_type = 'edited-book' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'edited-book' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'edited-book' AND unpaywall.gold) as is_gold),

                          STRUCT("reports" as type, 
                            COUNTIF(unpaywall.output_type = 'report') as count, 
                            COUNTIF(unpaywall.output_type = 'report' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'report' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'report' AND unpaywall.gold) as is_gold),

                          STRUCT("datasets" as type, 
                            COUNTIF(unpaywall.output_type = 'dataset') as count, 
                            COUNTIF(unpaywall.output_type = 'dataset' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'dataset' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'dataset' AND unpaywall.gold) as is_gold),

                          STRUCT("proceedings_article" as type, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article') as count, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article' AND unpaywall.gold) as is_gold),

                          STRUCT("other_outputs" as type, 
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article')) as count, 
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article') AND unpaywall.is_oa) as is_oa,
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article') AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article') AND unpaywall.gold) as is_gold)
                        ] as output_types
                        
                    FROM UNNEST(unpaywall_history) as unpaywall GROUP BY unpaywall.unpaywall_release)) as unpaywall_history
              ) as just_scopus,
          STRUCT(
              just_wos_total as total, just_wos_total_oa as total_oa,
              ARRAY((SELECT as STRUCT 
                        unpaywall.unpaywall_release, 
                        COUNT(*) as total, 
                        COUNTIF(is_oa) as total_oa, 
                        COUNTIF(green) as green, 
                        COUNTIF(gold) as gold,
                        -- Output type counts
                        [
                          STRUCT("journal_articles" as type, 
                            COUNTIF(unpaywall.output_type = 'journal-article') as count, 
                            COUNTIF(unpaywall.output_type = 'journal-article' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'journal-article' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'journal-article' AND unpaywall.gold) as is_gold),

                          STRUCT("book_sections" as type, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter')) as count, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter') AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter') AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter') AND unpaywall.gold) as is_gold),

                          STRUCT("authored_books" as type, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph')) as count, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph') AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph') AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph') AND unpaywall.gold) as is_gold),

                          STRUCT("edited_volumes" as type, 
                            COUNTIF(unpaywall.output_type = 'edited-book') as count, 
                            COUNTIF(unpaywall.output_type = 'edited-book' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'edited-book' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'edited-book' AND unpaywall.gold) as is_gold),

                          STRUCT("reports" as type, 
                            COUNTIF(unpaywall.output_type = 'report') as count, 
                            COUNTIF(unpaywall.output_type = 'report' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'report' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'report' AND unpaywall.gold) as is_gold),

                          STRUCT("datasets" as type, 
                            COUNTIF(unpaywall.output_type = 'dataset') as count, 
                            COUNTIF(unpaywall.output_type = 'dataset' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'dataset' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'dataset' AND unpaywall.gold) as is_gold),

                          STRUCT("proceedings_article" as type, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article') as count, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article' AND unpaywall.gold) as is_gold),

                          STRUCT("other_outputs" as type, 
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article')) as count, 
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article') AND unpaywall.is_oa) as is_oa,
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article') AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article') AND unpaywall.gold) as is_gold)
                        ] as output_types
                        
                    FROM UNNEST(unpaywall_history) as unpaywall GROUP BY unpaywall.unpaywall_release)) as unpaywall_history
              ) as just_wos,
          STRUCT(
              just_mag_total as total, just_mag_total_oa as total_oa,
              ARRAY((SELECT as STRUCT 
                        unpaywall.unpaywall_release, 
                        COUNT(*) as total, 
                        COUNTIF(is_oa) as total_oa, 
                        COUNTIF(green) as green, 
                        COUNTIF(gold) as gold,
                        -- Output type counts
                        [
                          STRUCT("journal_articles" as type, 
                            COUNTIF(unpaywall.output_type = 'journal-article') as count, 
                            COUNTIF(unpaywall.output_type = 'journal-article' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'journal-article' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'journal-article' AND unpaywall.gold) as is_gold),

                          STRUCT("book_sections" as type, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter')) as count, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter') AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter') AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter') AND unpaywall.gold) as is_gold),

                          STRUCT("authored_books" as type, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph')) as count, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph') AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph') AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type in ('book', 'monograph') AND unpaywall.gold) as is_gold),

                          STRUCT("edited_volumes" as type, 
                            COUNTIF(unpaywall.output_type = 'edited-book') as count, 
                            COUNTIF(unpaywall.output_type = 'edited-book' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'edited-book' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'edited-book' AND unpaywall.gold) as is_gold),

                          STRUCT("reports" as type, 
                            COUNTIF(unpaywall.output_type = 'report') as count, 
                            COUNTIF(unpaywall.output_type = 'report' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'report' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'report' AND unpaywall.gold) as is_gold),

                          STRUCT("datasets" as type, 
                            COUNTIF(unpaywall.output_type = 'dataset') as count, 
                            COUNTIF(unpaywall.output_type = 'dataset' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'dataset' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'dataset' AND unpaywall.gold) as is_gold),

                          STRUCT("proceedings_article" as type, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article') as count, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article' AND unpaywall.is_oa) as is_oa, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article' AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type = 'proceedings-article' AND unpaywall.gold) as is_gold),

                          STRUCT("other_outputs" as type, 
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article')) as count, 
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article') AND unpaywall.is_oa) as is_oa,
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article') AND unpaywall.green) as is_green, 
                            COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article') AND unpaywall.gold) as is_gold)
                        ] as output_types
                        
                    FROM UNNEST(unpaywall_history) as unpaywall GROUP BY unpaywall.unpaywall_release)) as unpaywall_history
              ) as just_mag
          )
         ) as years
  FROM(
    SELECT
      grid_id,
      dois.crossref.published_year,
      --ARRAY_AGG(STRUCT(doi, dois.unpaywall.is_oa)) as outputs, -- add in any additional fields

      ARRAY_CONCAT_AGG(grids.types) as types,
      MAX(grids.name) as name,
      MAX(grids.iso3166.regions.name) as country,
      MAX(grids.iso3166.regions.alpha3) as country_code,
      MAX(grids.iso3166.regions.region) as region,
      MAX(grids.iso3166.regions.subregion) as subregion,
      MAX( CONCAT(CAST(grids.addresses[SAFE_OFFSET(0)].lat as STRING), ", ", CAST(grids.addresses[SAFE_OFFSET(0)].lng as STRING))) as coordinates,

      -- Total outputs
      COUNT(doi) as total,
      COUNTIF(unpaywall.is_oa = True) as total_oa,
      
      --just_scopus
      COUNTIF(doi IS NOT NULL AND grid_id in UNNEST(scopus.grids)) as just_scopus_total,
      COUNTIF(unpaywall.is_oa = True AND grid_id in UNNEST(scopus.grids)) as just_scopus_total_oa,
      --just_wos
      COUNTIF(doi IS NOT NULL AND grid_id in UNNEST(wos.grids)) as just_wos_total,
      COUNTIF(unpaywall.is_oa = True AND grid_id in UNNEST(wos.grids)) as just_wos_total_oa,
      --just_mag
      COUNTIF(doi IS NOT NULL AND grid_id in UNNEST(microsoft_academic_graph.grids)) as just_mag_total,
      COUNTIF(unpaywall.is_oa = True AND grid_id in UNNEST(microsoft_academic_graph.grids)) as just_mag_total_oa,

      -- Citation counts
      SUM(open_citations.citations_total) as total_citations,
      COUNTIF(open_citations.citations_total > 0) as articles_with_citations,
      COUNTIF(open_citations.citations_total is null) as articles_without_citations,
      SUM(open_citations.citations_total) / COUNT(doi) as citations_per_article,
      SAFE_DIVIDE(SUM(open_citations.citations_total), COUNTIF(open_citations.citations_total > 0)) as citations_per_citated_article,
      
      -- Unpaywall History
      ARRAY_CONCAT_AGG( ARRAY((SELECT AS STRUCT unpaywall.* from UNNEST(dois.unpaywall_history) as unpaywall))) as unpaywall_history,
      ARRAY_CONCAT_AGG( ARRAY((SELECT AS STRUCT unpaywall.* from UNNEST(dois.unpaywall_history) as unpaywall WHERE grid_id in UNNEST(scopus.grids)))) as unpaywall_history_scopus,
      ARRAY_CONCAT_AGG( ARRAY((SELECT AS STRUCT unpaywall.* from UNNEST(dois.unpaywall_history) as unpaywall WHERE grid_id in UNNEST(wos.grids)))) as unpaywall_history_wos,
      ARRAY_CONCAT_AGG( ARRAY((SELECT AS STRUCT unpaywall.* from UNNEST(dois.unpaywall_history) as unpaywall WHERE grid_id in UNNEST(Microsoft_Academic_Graph.grids)))) as unpaywall_history_mag,

      --Citations against OA Status
      [
        STRUCT("Open Access" as oa_status, COUNTIF(unpaywall.is_oa = True) as articles, COUNTIF(open_citations.citations_total > 0 AND unpaywall.is_oa = True) as articles_with_citations, COUNTIF(open_citations.citations_total is null  AND unpaywall.is_oa = True) as articles_without_citations, SUM(IF(unpaywall.is_oa = True, open_citations.citations_total, 0)) as citations), 
        STRUCT("Not Open Access" as oa_status, COUNTIF(unpaywall.is_oa IS NOT True) as articles, COUNTIF(open_citations.citations_total > 0 AND unpaywall.is_oa IS NOT TRUE) as articles_with_citations, COUNTIF(open_citations.citations_total is null  AND unpaywall.is_oa IS NOT TRUE) as articles_without_citations, SUM(IF(unpaywall.is_oa IS NOT True, open_citations.citations_total, 0)) as ctiations )
      ] as oa_citations,

      [
        STRUCT(True as oa_status, COUNTIF(unpaywall.gold = True) as articles, COUNTIF(open_citations.citations_total > 0 AND unpaywall.gold = True) as articles_with_citations, COUNTIF(open_citations.citations_total is null  AND unpaywall.gold = True) as articles_without_citations, SUM(IF(unpaywall.gold = True, open_citations.citations_total, 0)) as citations), 
        STRUCT(False as oa_status, COUNTIF(unpaywall.gold IS NOT True) as articles, COUNTIF(open_citations.citations_total > 0 AND unpaywall.gold IS NOT TRUE) as articles_with_citations, COUNTIF(open_citations.citations_total is null  AND unpaywall.gold IS NOT TRUE) as articles_without_citations, SUM(IF(unpaywall.gold IS NOT True, open_citations.citations_total, 0)) as ctiations )
      ] as gold_citations,

      [
        STRUCT(True as oa_status, COUNTIF(unpaywall.green = True) as articles, COUNTIF(open_citations.citations_total > 0 AND unpaywall.green = True) as articles_with_citations, COUNTIF(open_citations.citations_total is null  AND unpaywall.green = True) as articles_without_citations, SUM(IF(unpaywall.green = True, open_citations.citations_total, 0)) as citations), 
        STRUCT(False as oa_status, COUNTIF(unpaywall.green IS NOT True) as articles, COUNTIF(open_citations.citations_total > 0 AND unpaywall.green IS NOT TRUE) as articles_with_citations, COUNTIF(open_citations.citations_total is null  AND unpaywall.green IS NOT TRUE) as articles_without_citations, SUM(IF(unpaywall.green IS NOT True, open_citations.citations_total, 0)) as ctiations )
      ] as green_citations,

      [
        STRUCT(True as oa_status, COUNTIF(unpaywall.green_only = True) as articles, COUNTIF(open_citations.citations_total > 0 AND unpaywall.green_only = True) as articles_with_citations, COUNTIF(open_citations.citations_total is null  AND unpaywall.green_only = True) as articles_without_citations, SUM(IF(unpaywall.green_only = True, open_citations.citations_total, 0)) as citations), 
        STRUCT(False as oa_status, COUNTIF(unpaywall.green_only IS NOT True) as articles, COUNTIF(open_citations.citations_total > 0 AND unpaywall.green_only IS NOT TRUE) as articles_with_citations, COUNTIF(open_citations.citations_total is null  AND unpaywall.green_only IS NOT TRUE) as articles_without_citations, SUM(IF(unpaywall.green_only IS NOT True, open_citations.citations_total, 0)) as ctiations )
      ] as green_only_citations,

      [
        STRUCT(True as oa_status, COUNTIF(unpaywall.hybrid = True) as articles, COUNTIF(open_citations.citations_total > 0 AND unpaywall.hybrid = True) as articles_with_citations, COUNTIF(open_citations.citations_total is null  AND unpaywall.hybrid = True) as articles_without_citations, SUM(IF(unpaywall.hybrid = True, open_citations.citations_total, 0)) as citations), 
        STRUCT(False as oa_status, COUNTIF(unpaywall.hybrid IS NOT True) as articles, COUNTIF(open_citations.citations_total > 0 AND unpaywall.hybrid IS NOT TRUE) as articles_with_citations, COUNTIF(open_citations.citations_total is null  AND unpaywall.hybrid IS NOT TRUE) as articles_without_citations, SUM(IF(unpaywall.hybrid IS NOT True, open_citations.citations_total, 0)) as ctiations )
      ] as hybrid_citations,

      [
        STRUCT(True as oa_status, COUNTIF(unpaywall.bronze = True) as articles, COUNTIF(open_citations.citations_total > 0 AND unpaywall.bronze = True) as articles_with_citations, COUNTIF(open_citations.citations_total is null  AND unpaywall.bronze = True) as articles_without_citations, SUM(IF(unpaywall.bronze = True, open_citations.citations_total, 0)) as citations), 
        STRUCT(False as oa_status, COUNTIF(unpaywall.bronze IS NOT True) as articles, COUNTIF(open_citations.citations_total > 0 AND unpaywall.bronze IS NOT TRUE) as articles_with_citations, COUNTIF(open_citations.citations_total is null  AND unpaywall.bronze IS NOT TRUE) as articles_without_citations, SUM(IF(unpaywall.bronze IS NOT True, open_citations.citations_total, 0)) as ctiations )
      ] as bronze_citations,


      -- OA counts for outputs
      [
        STRUCT(True as status, COUNTIF(unpaywall.is_oa = True) as count), 
        STRUCT(False as status, COUNTIF(unpaywall.is_oa IS NOT True) as count)
      ] as open_access,

      [
        STRUCT(True as status, COUNTIF(unpaywall.gold = True) as count), 
        STRUCT(False as status, COUNTIF(unpaywall.gold IS NOT True) as count)
      ] as gold,

      [
        STRUCT(True as status, COUNTIF(unpaywall.green = True) as count), 
        STRUCT(False as status, COUNTIF(unpaywall.green IS NOT True) as count)
      ] as green,

      [
        STRUCT(True as status, COUNTIF(unpaywall.green_only = True) as count), 
        STRUCT(False as status, COUNTIF(unpaywall.green_only IS NOT True) as count)
      ] as green_only,
      
      [
        STRUCT(True as status, COUNTIF(STRPOS(ARRAY_TO_STRING(unpaywall.repository_locations, '--'), grids.home_repo) > 0) as count), 
        STRUCT(False as status, COUNTIF(STRPOS(ARRAY_TO_STRING(unpaywall.repository_locations, '--'), grids.home_repo) <= 0) as count)
      ] as green_in_home_repo,

      [
        STRUCT(True as status, COUNTIF(unpaywall.hybrid = True) as count), 
        STRUCT(False as status, COUNTIF(unpaywall.hybrid IS NOT True) as count)
      ] as hybrid,

      [
        STRUCT(True as status, COUNTIF(unpaywall.bronze = True) as count), 
        STRUCT(False as status, COUNTIF(unpaywall.bronze IS NOT True) as count)
      ] as bronze,

      -- OA percentages for outputs
      (COUNTIF(unpaywall.is_oa is True)) * 100 / COUNT(doi) as percent_OA,
      (COUNTIF(unpaywall.green is True)) * 100 / COUNT(doi) as percent_green,
      (COUNTIF(unpaywall.green_only is True)) * 100 / COUNT(doi) as percent_green_only,
      (COUNTIF(STRPOS(ARRAY_TO_STRING(unpaywall.repository_locations, '--'), grids.home_repo) > 0)) * 100 / COUNT(doi) as percent_in_home_repo,
      SAFE_DIVIDE((COUNTIF(STRPOS(ARRAY_TO_STRING(unpaywall.repository_locations, '--'), grids.home_repo) > 0)) * 100, COUNTIF(unpaywall.green is True)) as percent_of_just_green_in_home_repo,
      (COUNTIF(unpaywall.gold is True)) * 100 / COUNT(doi) as percent_gold,
      (COUNTIF(unpaywall.gold_just_doaj is True)) * 100 / COUNT(doi) as percent_gold_doaj,
      (COUNTIF(unpaywall.hybrid is True)) * 100 / COUNT(doi) as percent_hybrid,
      (COUNTIF(unpaywall.bronze is True)) * 100 / COUNT(doi) as percent_bronze,

      -- Output type counts
      [
        STRUCT("journal_articles" as type, 
          COUNTIF(unpaywall.output_type = 'journal-article') as count, 
          COUNTIF(unpaywall.output_type = 'journal-article' AND unpaywall.is_oa) as is_oa, 
          COUNTIF(unpaywall.output_type = 'journal-article' AND unpaywall.green) as is_green, 
          COUNTIF(unpaywall.output_type = 'journal-article' AND unpaywall.gold) as is_gold),
        
        STRUCT("book_sections" as type, 
          COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter')) as count, 
          COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter') AND unpaywall.is_oa) as is_oa, 
          COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter') AND unpaywall.green) as is_green, 
          COUNTIF(unpaywall.output_type in ('book-section', 'book-part', 'book-chapter') AND unpaywall.gold) as is_gold),
        
        STRUCT("authored_books" as type, 
          COUNTIF(unpaywall.output_type in ('book', 'monograph')) as count, 
          COUNTIF(unpaywall.output_type in ('book', 'monograph') AND unpaywall.is_oa) as is_oa, 
          COUNTIF(unpaywall.output_type in ('book', 'monograph') AND unpaywall.green) as is_green, 
          COUNTIF(unpaywall.output_type in ('book', 'monograph') AND unpaywall.gold) as is_gold),
        
        STRUCT("edited_volumes" as type, 
          COUNTIF(unpaywall.output_type = 'edited-book') as count, 
          COUNTIF(unpaywall.output_type = 'edited-book' AND unpaywall.is_oa) as is_oa, 
          COUNTIF(unpaywall.output_type = 'edited-book' AND unpaywall.green) as is_green, 
          COUNTIF(unpaywall.output_type = 'edited-book' AND unpaywall.gold) as is_gold),
        
        STRUCT("reports" as type, 
          COUNTIF(unpaywall.output_type = 'report') as count, 
          COUNTIF(unpaywall.output_type = 'report' AND unpaywall.is_oa) as is_oa, 
          COUNTIF(unpaywall.output_type = 'report' AND unpaywall.green) as is_green, 
          COUNTIF(unpaywall.output_type = 'report' AND unpaywall.gold) as is_gold),
        
        STRUCT("datasets" as type, 
          COUNTIF(unpaywall.output_type = 'dataset') as count, 
          COUNTIF(unpaywall.output_type = 'dataset' AND unpaywall.is_oa) as is_oa, 
          COUNTIF(unpaywall.output_type = 'dataset' AND unpaywall.green) as is_green, 
          COUNTIF(unpaywall.output_type = 'dataset' AND unpaywall.gold) as is_gold),
        
        STRUCT("proceedings_article" as type, 
          COUNTIF(unpaywall.output_type = 'proceedings-article') as count, 
          COUNTIF(unpaywall.output_type = 'proceedings-article' AND unpaywall.is_oa) as is_oa, 
          COUNTIF(unpaywall.output_type = 'proceedings-article' AND unpaywall.green) as is_green, 
          COUNTIF(unpaywall.output_type = 'proceedings-article' AND unpaywall.gold) as is_gold),
        
        STRUCT("other_outputs" as type, 
          COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article')) as count, 
          COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article') AND unpaywall.is_oa) as is_oa,
          COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article') AND unpaywall.green) as is_green, 
          COUNTIF(unpaywall.output_type not in ('journal-article', 'book-section', 'book-part', 'book-chapter','book', 'monograph','edited-book', 'report', 'dataset', 'proceedings-article') AND unpaywall.gold) as is_gold)
      ] as output_types,

      -- Events  
      ARRAY_CONCAT_AGG(dois.events.events) as alt_metrics,    

      -- Funders
      --ARRAY_AGG( STRUCT( dois.crossref.funder as funder,  unpaywall.is_oa as is_oa)) as funders,
      ARRAY_CONCAT_AGG( ARRAY((SELECT AS STRUCT funder.DOI, funder.name, unpaywall.is_oa as is_oa, unpaywall.green as green, unpaywall.gold as gold from UNNEST(dois.crossref.funder) as funder))) as funders,

      -- Publishers
      ARRAY_AGG(STRUCT(crossref.publisher as publisher, unpaywall.is_oa as is_oa, unpaywall.green as green, unpaywall.gold as gold)) as publishers,

      -- Journals
      ARRAY_AGG(STRUCT(unpaywall.journal_name as journal, unpaywall.is_oa as is_oa, unpaywall.green as green, unpaywall.gold as gold)) as journals 

    FROM `academic-observatory.doi.dois_2020_01_26` as dois, UNNEST( ARRAY(SELECT DISTINCT grid FROM UNNEST( ARRAY_CONCAT( IF(microsoft_academic_graph.grids IS NOT NULL, microsoft_academic_graph.grids, []), IF( wos.grids IS NOT NULL, wos.grids, []), IF(scopus.grids IS NOT NULL, scopus.grids, []))) AS grid )) as grid_id
    LEFT JOIN `academic-observatory-workflow.grid_processed.grid_extended_2019_12_10` as grids on grid_id = grids.id
    GROUP BY
      grid_id, crossref.published_year) as base
  LEFT JOIN (SELECT
                grid_id,
                published_year,
                ARRAY(SELECT AS STRUCT grids.grid as grid_id, 
                                       COUNT(grids) as count,
                                       MAX(grids.name) as name,
                                       MAX(grids.country) as country,
                                       MAX(grids.region) as region,
                                       MAX(grids.subregion) as subregion,
                                       MAX(grids.coordinates) as coordinates
                  FROM UNNEST(collaborations) as grids WHERE grids.grid <> grid_id GROUP BY grids.grid ) as collaborations
              FROM(SELECT
                grid_id,
                published_year,

                MAX(home.name) as name,
                MAX(home.country) as country,
                MAX(home.region) as region,
                MAX(home.subregion) as subregion,
                MAX(home.coordinates ) as coordinates,
                ARRAY_AGG(STRUCT(
                collaborators as grid,
                colaborator.name as name,
                colaborator.iso3166.regions.region as region,
                colaborator.iso3166.regions.subregion as subregion,
                CONCAT(CAST(colaborator.addresses[SAFE_OFFSET(0)].lat as STRING), ", ", CAST(colaborator.addresses[SAFE_OFFSET(0)].lng as STRING)) as coordinates,
                colaborator.iso3166.regions.name as country,
                colaborator.iso3166.regions.alpha3 as country_code)) as collaborations
              FROM(
                SELECT
                  grid_id,
                  dois.crossref.published_year,    
                  MAX(grids.name) as name,
                  MAX(grids.iso3166.regions.name) as country,
                  MAX(grids.iso3166.regions.alpha3) as country_code,
                  MAX(grids.iso3166.regions.region) as region,
                  MAX(grids.iso3166.regions.subregion) as subregion,
                  MAX( CONCAT(CAST(grids.addresses[SAFE_OFFSET(0)].lat as STRING), ", ", CAST(grids.addresses[SAFE_OFFSET(0)].lng as STRING))) as coordinates,
                  ARRAY_CONCAT_AGG( ARRAY_CONCAT(IF(microsoft_academic_graph.grids IS NOT NULL, microsoft_academic_graph.grids, []), IF( wos.grids IS NOT NULL, wos.grids, []), IF(scopus.grids IS NOT NULL, scopus.grids, []))) as collaborations
                FROM `academic-observatory.doi.dois_2020_01_26` as dois, UNNEST( ARRAY(SELECT DISTINCT grid FROM UNNEST( ARRAY_CONCAT( IF(microsoft_academic_graph.grids IS NOT NULL, microsoft_academic_graph.grids, []), IF( wos.grids IS NOT NULL, wos.grids, []), IF(scopus.grids IS NOT NULL, scopus.grids, []))) AS grid )) as grid_id
                LEFT JOIN `academic-observatory-workflow.grid_processed.grid_extended_2019_12_10` as grids on grid_id = grids.id
                GROUP BY
                  grid_id, crossref.published_year) as home, UNNEST(collaborations) as collaborators
              LEFT JOIN `academic-observatory-workflow.grid_processed.grid_extended_2019_12_10` as colaborator on collaborators = colaborator.id
              GROUP BY grid_id, home.published_year)
  ) as collaborators on collaborators.grid_id = base.grid_id AND collaborators.published_year = base.published_year
  LEFT JOIN `academic-observatory-telescope.coki_diversity.diversity_2019_08` as diversity on diversity.grid_id = base.grid_id AND diversity.year = base.published_year
  GROUP BY
    base.grid_id)